Class: Aws::RedshiftDataAPIService::Types::BatchExecuteStatementInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::BatchExecuteStatementInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
-
#cluster_identifier ⇒ String
The cluster identifier.
-
#database ⇒ String
The name of the database.
-
#db_user ⇒ String
The database user name.
-
#execution_mode ⇒ String
Determines how the SQL statements in the batch are run.
-
#parameters ⇒ Array<Types::SqlParameter>
The parameters for the SQL statements.
-
#result_format ⇒ String
The data format of the result of the SQL statement.
-
#secret_arn ⇒ String
The name or ARN of the secret that enables access to the database.
-
#session_id ⇒ String
The session identifier of the query.
-
#session_keep_alive_seconds ⇒ Integer
The number of seconds to keep the session alive after the query finishes.
-
#sqls ⇒ Array<String>
One or more SQL statements to run.
-
#statement_name ⇒ String
The name of the SQL statements.
-
#wait_time_seconds ⇒ Integer
The number of seconds to wait for all SQL statements in the batch to complete execution before returning the response.
-
#with_event ⇒ Boolean
A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statements run.
-
#workgroup_name ⇒ String
The serverless workgroup name or Amazon Resource Name (ARN).
Instance Attribute Details
#client_token ⇒ String
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
A suitable default value is auto-generated. You should normally not need to pass this option.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#cluster_identifier ⇒ String
The cluster identifier. This parameter is required when connecting to a cluster and authenticating using either Secrets Manager or temporary credentials.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#db_user ⇒ String
The database user name. This parameter is required when connecting to a cluster as a database user and authenticating using temporary credentials.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#execution_mode ⇒ String
Determines how the SQL statements in the batch are run. If set to
TRANSACTION (the default), all SQL statements are run as a single
transaction and they are committed or rolled back together. If set
to AUTO_COMMIT, each SQL statement is committed individually, and
a failure of one statement does not affect the others.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::SqlParameter>
The parameters for the SQL statements. The parameters are available to all SQL statements in the batch. Each statement can reference any subset of the provided parameters. Each provided parameter must be referenced by at least one SQL statement in the batch.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#result_format ⇒ String
The data format of the result of the SQL statement. If no format is specified, the default is JSON.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The session identifier of the query.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#session_keep_alive_seconds ⇒ Integer
The number of seconds to keep the session alive after the query finishes. The maximum time a session can keep alive is 24 hours. After 24 hours, the session is forced closed and the query is terminated.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#sqls ⇒ Array<String>
One or more SQL statements to run. The SQL statements run serially
in the order of the array. Subsequent SQL statements don't start
until the previous statement in the array completes. By default, the
SQL statements are run as a single transaction. If any SQL statement
fails, all work is rolled back. To change this behavior, see the
ExecutionMode parameter.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#statement_name ⇒ String
The name of the SQL statements. You can name the SQL statements when you create them to identify the query.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#wait_time_seconds ⇒ Integer
The number of seconds to wait for all SQL statements in the batch to complete execution before returning the response. If the SQL statements do not complete within the specified time, the response returns the current status. The maximum value is 30 seconds.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#with_event ⇒ Boolean
A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statements run.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The serverless workgroup name or Amazon Resource Name (ARN). This parameter is required when connecting to a serverless workgroup and authenticating using either Secrets Manager or temporary credentials.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 170 class BatchExecuteStatementInput < Struct.new( :sqls, :cluster_identifier, :secret_arn, :db_user, :database, :with_event, :statement_name, :parameters, :workgroup_name, :client_token, :result_format, :session_keep_alive_seconds, :session_id, :execution_mode, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |