Class: Aws::RedshiftDataAPIService::Types::BatchExecuteStatementOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftdataapiservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The cluster identifier. This element is not returned when connecting to a serverless workgroup.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time (UTC) the statement was created.

Returns:

  • (Time)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#db_groupsArray<String>

A list of colon (:) separated names of database groups.

Returns:

  • (Array<String>)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#db_userString

The database user name.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#has_result_setBoolean

A value that indicates whether the statement has a result set. The result set can be empty. The value is true for an empty result set. The value is true if any substatement returns a result set.

Returns:

  • (Boolean)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the SQL statement whose results are to be fetched. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. This identifier is returned by BatchExecuteStatment.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#redshift_pidInteger

The process identifier from Amazon Redshift.

Returns:

  • (Integer)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The name or ARN of the secret that enables access to the database.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The session identifier of the query.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SQL statement. Status values are defined as follows:

  • ABORTED - The query run was stopped by the user.

  • FAILED - The query run failed.

  • FINISHED - The query has finished running.

  • PICKED - The query has been chosen to be run.

  • STARTED - The query run has started.

  • SUBMITTED - The query was submitted, but not yet processed.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_nameString

The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.

Returns:

  • (String)


260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260

class BatchExecuteStatementOutput < Struct.new(
  :id,
  :created_at,
  :cluster_identifier,
  :db_user,
  :db_groups,
  :database,
  :secret_arn,
  :workgroup_name,
  :session_id,
  :status,
  :redshift_pid,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end