Class: Aws::RedshiftDataAPIService::Types::ColumnMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::ColumnMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
The properties (metadata) of a column.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#column_default ⇒ String
The default value of the column.
-
#is_case_sensitive ⇒ Boolean
A value that indicates whether the column is case-sensitive.
-
#is_currency ⇒ Boolean
A value that indicates whether the column contains currency values.
-
#is_signed ⇒ Boolean
A value that indicates whether an integer column is signed.
-
#label ⇒ String
The label for the column.
-
#length ⇒ Integer
The length of the column.
-
#name ⇒ String
The name of the column.
-
#nullable ⇒ Integer
A value that indicates whether the column is nullable.
-
#precision ⇒ Integer
The precision value of a decimal number column, or the column length for a non-numeric column.
-
#scale ⇒ Integer
The scale value of a decimal number column.
-
#schema_name ⇒ String
The name of the schema that contains the table that includes the column.
-
#table_name ⇒ String
The name of the table that includes the column.
-
#type_name ⇒ String
The database-specific data type of the column.
Instance Attribute Details
#column_default ⇒ String
The default value of the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#is_case_sensitive ⇒ Boolean
A value that indicates whether the column is case-sensitive.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#is_currency ⇒ Boolean
A value that indicates whether the column contains currency values.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#is_signed ⇒ Boolean
A value that indicates whether an integer column is signed.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#label ⇒ String
The label for the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#length ⇒ Integer
The length of the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#nullable ⇒ Integer
A value that indicates whether the column is nullable.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#precision ⇒ Integer
The precision value of a decimal number column, or the column length for a non-numeric column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#scale ⇒ Integer
The scale value of a decimal number column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#schema_name ⇒ String
The name of the schema that contains the table that includes the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table that includes the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |
#type_name ⇒ String
The database-specific data type of the column.
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 363 class ColumnMetadata < Struct.new( :is_case_sensitive, :is_currency, :is_signed, :label, :name, :nullable, :precision, :scale, :schema_name, :table_name, :type_name, :length, :column_default) SENSITIVE = [] include Aws::Structure end |