Class: Aws::RedshiftDataAPIService::Types::DescribeStatementRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::DescribeStatementRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the SQL statement to describe.
-
#wait_time_seconds ⇒ Integer
The number of seconds to wait for the SQL statement to complete execution before returning the description.
Instance Attribute Details
#id ⇒ String
The identifier of the SQL statement to describe. This value is a
universally unique identifier (UUID) generated by Amazon Redshift
Data API. A suffix indicates the number of the SQL statement. For
example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has a suffix of
:2 that indicates the second SQL statement of a batch query. This
identifier is returned by BatchExecuteStatment,
ExecuteStatement, and ListStatements.
412 413 414 415 416 417 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 412 class DescribeStatementRequest < Struct.new( :id, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#wait_time_seconds ⇒ Integer
The number of seconds to wait for the SQL statement to complete execution before returning the description. The maximum value is 30 seconds.
412 413 414 415 416 417 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 412 class DescribeStatementRequest < Struct.new( :id, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |