Class: Aws::RedshiftDataAPIService::Types::GetStatementResultRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::GetStatementResultRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The identifier of the SQL statement whose results are to be fetched.
-
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#wait_time_seconds ⇒ Integer
The number of seconds to wait for the SQL statement to complete execution before returning the result.
Instance Attribute Details
#id ⇒ String
The identifier of the SQL statement whose results are to be fetched.
This value is a universally unique identifier (UUID) generated by
Amazon Redshift Data API. A suffix indicates then number of the SQL
statement. For example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has
a suffix of :2 that indicates the second SQL statement of a batch
query. This identifier is returned by BatchExecuteStatment,
ExecuteStatment, and ListStatements.
958 959 960 961 962 963 964 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 958 class GetStatementResultRequest < Struct.new( :id, :next_token, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
958 959 960 961 962 963 964 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 958 class GetStatementResultRequest < Struct.new( :id, :next_token, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |
#wait_time_seconds ⇒ Integer
The number of seconds to wait for the SQL statement to complete execution before returning the result. The maximum value is 30 seconds.
958 959 960 961 962 963 964 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 958 class GetStatementResultRequest < Struct.new( :id, :next_token, :wait_time_seconds) SENSITIVE = [] include Aws::Structure end |