Class: Aws::RedshiftDataAPIService::Types::GetStatementResultV2Request

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftdataapiservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier of the SQL statement whose results are to be fetched. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. A suffix indicates then number of the SQL statement. For example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has a suffix of :2 that indicates the second SQL statement of a batch query. This identifier is returned by BatchExecuteStatment, ExecuteStatment, and ListStatements.

Returns:

  • (String)


1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1027

class GetStatementResultV2Request < Struct.new(
  :id,
  :next_token,
  :wait_time_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1027

class GetStatementResultV2Request < Struct.new(
  :id,
  :next_token,
  :wait_time_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#wait_time_secondsInteger

The number of seconds to wait for the SQL statement to complete execution before returning the result. The maximum value is 30 seconds.

Returns:

  • (Integer)


1027
1028
1029
1030
1031
1032
1033
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1027

class GetStatementResultV2Request < Struct.new(
  :id,
  :next_token,
  :wait_time_seconds)
  SENSITIVE = []
  include Aws::Structure
end