Class: Aws::RedshiftDataAPIService::Types::ListSessionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftdataapiservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The cluster identifier. Only sessions on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.

Returns:

  • (String)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database. Only sessions connected to this database are returned.

Returns:

  • (String)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of sessions to return in the response. If more sessions exist than fit in one response, the operation returns NextToken to paginate the results.

Returns:

  • (Integer)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#role_levelBoolean

Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.

Returns:

  • (Boolean)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#session_idString

The identifier of a specific session to return metadata for. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. When you provide SessionId, you can't specify Status, ClusterIdentifier, WorkgroupName, or Database.

Returns:

  • (String)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the sessions to list. If no status is specified, sessions with a status of AVAILABLE or BUSY are returned. Status values are defined as follows:

  • AVAILABLE – The session is open and ready to run a SQL statement.

  • BUSY – The session is currently running a SQL statement.

  • CLOSED – The session is closed and can no longer run SQL statements.

Returns:

  • (String)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_nameString

The serverless workgroup name or Amazon Resource Name (ARN). Only sessions on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.

Returns:

  • (String)


1327
1328
1329
1330
1331
1332
1333
1334
1335
1336
1337
1338
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327

class ListSessionsRequest < Struct.new(
  :next_token,
  :max_results,
  :session_id,
  :status,
  :role_level,
  :cluster_identifier,
  :workgroup_name,
  :database)
  SENSITIVE = []
  include Aws::Structure
end