Class: Aws::RedshiftDataAPIService::Types::ListStatementsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftdataapiservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cluster_identifierString

The cluster identifier. Only statements that ran on this cluster are returned. When providing ClusterIdentifier, then WorkgroupName can't be specified.

Returns:

  • (String)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#databaseString

The name of the database when listing statements run against a ClusterIdentifier or WorkgroupName.

Returns:

  • (String)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of SQL statements to return in the response. If more SQL statements exist than fit in one response, then NextToken is returned to page through the results.

Returns:

  • (Integer)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_levelBoolean

A value that filters which statements to return in the response. If true, all statements run by the caller's IAM role are returned. If false, only statements run by the caller's IAM role in the current IAM session are returned. The default is true.

Returns:

  • (Boolean)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#statement_nameString

The name of the SQL statement specified as input to BatchExecuteStatement or ExecuteStatement to identify the query. You can list multiple statements by providing a prefix that matches the beginning of the statement name. For example, to list myStatement1, myStatement2, myStatement3, and so on, then provide the a value of myStatement. Data API does a case-sensitive match of SQL statement names to the prefix value you provide.

Returns:

  • (String)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SQL statement to list. Status values are defined as follows:

  • ABORTED - The query run was stopped by the user.

  • ALL - A status value that includes all query statuses. This value can be used to filter results.

  • FAILED - The query run failed.

  • FINISHED - The query has finished running.

  • PICKED - The query has been chosen to be run.

  • STARTED - The query run has started.

  • SUBMITTED - The query was submitted, but not yet processed.

Returns:

  • (String)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end

#workgroup_nameString

The serverless workgroup name or Amazon Resource Name (ARN). Only statements that ran on this workgroup are returned. When providing WorkgroupName, then ClusterIdentifier can't be specified.

Returns:

  • (String)


1433
1434
1435
1436
1437
1438
1439
1440
1441
1442
1443
1444
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1433

class ListStatementsRequest < Struct.new(
  :next_token,
  :max_results,
  :statement_name,
  :status,
  :role_level,
  :database,
  :cluster_identifier,
  :workgroup_name)
  SENSITIVE = []
  include Aws::Structure
end