Class: Aws::RedshiftDataAPIService::Types::ListStatementsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::ListStatementsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#statements ⇒ Array<Types::StatementData>
The SQL statements.
Instance Attribute Details
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
1461 1462 1463 1464 1465 1466 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1461 class ListStatementsResponse < Struct.new( :statements, :next_token) SENSITIVE = [] include Aws::Structure end |
#statements ⇒ Array<Types::StatementData>
The SQL statements.
1461 1462 1463 1464 1465 1466 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1461 class ListStatementsResponse < Struct.new( :statements, :next_token) SENSITIVE = [] include Aws::Structure end |