Class: Aws::RedshiftDataAPIService::Types::ListTablesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftdataapiservice/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.

Returns:

  • (String)


1571
1572
1573
1574
1575
1576
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1571

class ListTablesResponse < Struct.new(
  :tables,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#tablesArray<Types::TableMember>

The tables that match the request pattern.

Returns:



1571
1572
1573
1574
1575
1576
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1571

class ListTablesResponse < Struct.new(
  :tables,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end