Class: Aws::RedshiftDataAPIService::Types::SqlParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::SqlParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
A parameter used in a SQL statement.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
The name of the parameter.
-
#value ⇒ String
The value of the parameter.
Instance Attribute Details
#name ⇒ String
The name of the parameter.
1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1732 class SqlParameter < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the parameter. Amazon Redshift implicitly converts to the proper data type. For more information, see Data types in the Amazon Redshift Database Developer Guide.
1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1732 class SqlParameter < Struct.new( :name, :value) SENSITIVE = [] include Aws::Structure end |