Class: Aws::RedshiftDataAPIService::Types::StatementData
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::StatementData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
The SQL statement to run.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time (UTC) the statement was created.
-
#id ⇒ String
The SQL statement identifier.
-
#is_batch_statement ⇒ Boolean
A value that indicates whether the statement is a batch query request.
-
#query_parameters ⇒ Array<Types::SqlParameter>
The parameters used in a SQL statement.
-
#query_string ⇒ String
The SQL statement.
-
#query_strings ⇒ Array<String>
One or more SQL statements.
-
#result_format ⇒ String
The data format of the result of the SQL statement.
-
#secret_arn ⇒ String
The name or Amazon Resource Name (ARN) of the secret that enables access to the database.
-
#session_id ⇒ String
The session identifier of the query.
-
#statement_name ⇒ String
The name of the SQL statement.
-
#status ⇒ String
The status of the SQL statement.
-
#updated_at ⇒ Time
The date and time (UTC) that the statement metadata was last updated.
Instance Attribute Details
#created_at ⇒ Time
The date and time (UTC) the statement was created.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The SQL statement identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#is_batch_statement ⇒ Boolean
A value that indicates whether the statement is a batch query request.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#query_parameters ⇒ Array<Types::SqlParameter>
The parameters used in a SQL statement.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#query_string ⇒ String
The SQL statement.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#query_strings ⇒ Array<String>
One or more SQL statements. Each query string in the array corresponds to one of the queries in a batch query request.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#result_format ⇒ String
The data format of the result of the SQL statement.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The name or Amazon Resource Name (ARN) of the secret that enables access to the database.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The session identifier of the query.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#statement_name ⇒ String
The name of the SQL statement.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the SQL statement. An example is the that the SQL statement finished.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The date and time (UTC) that the statement metadata was last updated.
1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 1812 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1797 class StatementData < Struct.new( :id, :query_string, :query_strings, :secret_arn, :status, :statement_name, :created_at, :updated_at, :query_parameters, :is_batch_statement, :result_format, :session_id) SENSITIVE = [] include Aws::Structure end |