Class: Aws::RedshiftDataAPIService::Types::SubStatementData

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-redshiftdataapiservice/types.rb

Overview

Information about an SQL statement.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The date and time (UTC) the statement was created.

Returns:

  • (Time)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#durationInteger

The amount of time in nanoseconds that the statement ran.

Returns:

  • (Integer)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#errorString

The error message from the cluster if the SQL statement encountered an error while running.

Returns:

  • (String)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#has_result_setBoolean

A value that indicates whether the statement has a result set. The result set can be empty. The value is true for an empty result set.

Returns:

  • (Boolean)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the SQL statement. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API. A suffix indicates the number of the SQL statement. For example, d9b6c0c9-0747-4bf4-b142-e8883122f766:2 has a suffix of :2 that indicates the second SQL statement of a batch query.

Returns:

  • (String)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#query_stringString

The SQL statement text.

Returns:

  • (String)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#redshift_query_idInteger

The SQL statement identifier. This value is a universally unique identifier (UUID) generated by Amazon Redshift Data API.

Returns:

  • (Integer)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#result_rowsInteger

Either the number of rows returned from the SQL statement or the number of rows affected. If result size is greater than zero, the result rows can be the number of rows affected by SQL statements such as INSERT, UPDATE, DELETE, COPY, and others. A -1 indicates the value is null.

Returns:

  • (Integer)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#result_sizeInteger

The size in bytes of the returned results. A -1 indicates the value is null.

Returns:

  • (Integer)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the SQL statement. An example is the that the SQL statement finished.

Returns:

  • (String)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time (UTC) that the statement metadata was last updated.

Returns:

  • (Time)


1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1876

class SubStatementData < Struct.new(
  :id,
  :duration,
  :error,
  :status,
  :created_at,
  :updated_at,
  :query_string,
  :result_rows,
  :result_size,
  :redshift_query_id,
  :has_result_set)
  SENSITIVE = []
  include Aws::Structure
end