Class: Aws::RedshiftDataAPIService::Types::BatchExecuteStatementOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::BatchExecuteStatementOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The cluster identifier.
-
#created_at ⇒ Time
The date and time (UTC) the statement was created.
-
#database ⇒ String
The name of the database.
-
#db_groups ⇒ Array<String>
A list of colon (:) separated names of database groups.
-
#db_user ⇒ String
The database user name.
-
#has_result_set ⇒ Boolean
A value that indicates whether the statement has a result set.
-
#id ⇒ String
The identifier of the SQL statement whose results are to be fetched.
-
#redshift_pid ⇒ Integer
The process identifier from Amazon Redshift.
-
#secret_arn ⇒ String
The name or ARN of the secret that enables access to the database.
-
#session_id ⇒ String
The session identifier of the query.
-
#status ⇒ String
The status of the SQL statement.
-
#workgroup_name ⇒ String
The serverless workgroup name or Amazon Resource Name (ARN).
Instance Attribute Details
#cluster_identifier ⇒ String
The cluster identifier. This element is not returned when connecting to a serverless workgroup.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#created_at ⇒ Time
The date and time (UTC) the statement was created.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#db_groups ⇒ Array<String>
A list of colon (:) separated names of database groups.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#db_user ⇒ String
The database user name.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#has_result_set ⇒ Boolean
A value that indicates whether the statement has a result set. The result set can be empty. The value is true for an empty result set. The value is true if any substatement returns a result set.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The identifier of the SQL statement whose results are to be fetched.
This value is a universally unique identifier (UUID) generated by
Amazon Redshift Data API. This identifier is returned by
BatchExecuteStatment.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#redshift_pid ⇒ Integer
The process identifier from Amazon Redshift.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The name or ARN of the secret that enables access to the database.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The session identifier of the query.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the SQL statement. Status values are defined as follows:
-
ABORTED - The query run was stopped by the user.
-
FAILED - The query run failed.
-
FINISHED - The query has finished running.
-
PICKED - The query has been chosen to be run.
-
STARTED - The query run has started.
-
SUBMITTED - The query was submitted, but not yet processed.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The serverless workgroup name or Amazon Resource Name (ARN). This element is not returned when connecting to a provisioned cluster.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 260 class BatchExecuteStatementOutput < Struct.new( :id, :created_at, :cluster_identifier, :db_user, :db_groups, :database, :secret_arn, :workgroup_name, :session_id, :status, :redshift_pid, :has_result_set) SENSITIVE = [] include Aws::Structure end |