Class: Aws::RedshiftDataAPIService::Types::ListSessionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::ListSessionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cluster_identifier ⇒ String
The cluster identifier.
-
#database ⇒ String
The name of the database.
-
#max_results ⇒ Integer
The maximum number of sessions to return in the response.
-
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#role_level ⇒ Boolean
Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions.
-
#session_id ⇒ String
The identifier of a specific session to return metadata for.
-
#status ⇒ String
The status of the sessions to list.
-
#workgroup_name ⇒ String
The serverless workgroup name or Amazon Resource Name (ARN).
Instance Attribute Details
#cluster_identifier ⇒ String
The cluster identifier. Only sessions on this cluster are returned.
When providing ClusterIdentifier, then WorkgroupName can't be
specified.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#database ⇒ String
The name of the database. Only sessions connected to this database are returned.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of sessions to return in the response. If more
sessions exist than fit in one response, the operation returns
NextToken to paginate the results.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#role_level ⇒ Boolean
Specifies whether to return all sessions created by the caller's IAM role, including sessions from previous IAM sessions. If false, only sessions created in the current IAM session are returned. The default is true.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#session_id ⇒ String
The identifier of a specific session to return metadata for. This
value is a universally unique identifier (UUID) generated by Amazon
Redshift Data API. When you provide SessionId, you can't specify
Status, ClusterIdentifier, WorkgroupName, or Database.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the sessions to list. If no status is specified,
sessions with a status of AVAILABLE or BUSY are returned. Status
values are defined as follows:
-
AVAILABLE – The session is open and ready to run a SQL statement.
-
BUSY – The session is currently running a SQL statement.
-
CLOSED – The session is closed and can no longer run SQL statements.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |
#workgroup_name ⇒ String
The serverless workgroup name or Amazon Resource Name (ARN). Only
sessions on this workgroup are returned. When providing
WorkgroupName, then ClusterIdentifier can't be specified.
1327 1328 1329 1330 1331 1332 1333 1334 1335 1336 1337 1338 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1327 class ListSessionsRequest < Struct.new( :next_token, :max_results, :session_id, :status, :role_level, :cluster_identifier, :workgroup_name, :database) SENSITIVE = [] include Aws::Structure end |