Class: Aws::RedshiftDataAPIService::Types::ListSessionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RedshiftDataAPIService::Types::ListSessionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-redshiftdataapiservice/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request.
-
#sessions ⇒ Array<Types::SessionData>
The sessions that match the request.
Instance Attribute Details
#next_token ⇒ String
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request.
1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1355 class ListSessionsResponse < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |
#sessions ⇒ Array<Types::SessionData>
The sessions that match the request.
1355 1356 1357 1358 1359 1360 |
# File 'lib/aws-sdk-redshiftdataapiservice/types.rb', line 1355 class ListSessionsResponse < Struct.new( :sessions, :next_token) SENSITIVE = [] include Aws::Structure end |